@@ -23,7 +23,7 @@
 
 namespace Analitza {
 class Expression;
-};
+}
 
 /**
  * \class RangeCommand
@@ -61,7 +61,7 @@ class Expression;
 class RangeCommand: public Analitza::FunctionDefinition
 {
 public:
-    virtual Analitza::Expression operator()(const QList< Analitza::Expression >& args);
+    virtual Analitza::Expression operator()(const QList< Analitza::Expression >& args) override;
     
     static const QString id;
     static const Analitza::ExpressionType type;
